@@ -22,6 +22,7 @@ PROPS = (
     "site_data_dir",
     "site_config_dir",
     "site_cache_dir",
+    "site_runtime_dir",
 )
 
 
@@ -33,8 +34,7 @@ def func(request: SubRequest) -> str:
 @pytest.fixture(params=PROPS)
 def func_path(request: SubRequest) -> str:
     prop = cast(str, request.param)
-    prop = prop.replace("_dir", "_path")
-    return prop
+    return prop.replace("_dir", "_path")
 
 
 @pytest.fixture()
