@@ -5,7 +5,6 @@ import sys
 from pathlib import Path
 
 import pytest
-from _pytest.monkeypatch import MonkeyPatch
 
 import platformdirs
 from platformdirs.android import Android
@@ -55,8 +54,8 @@ def test_function_interface_is_in_sync(func: str) -> None:
 @pytest.mark.parametrize("path", ["/data/data/a/files", "/C"])
 @pytest.mark.parametrize("shell", ["/data/data/com.app/files/usr/bin/sh", "/usr/bin/sh", None])
 @pytest.mark.parametrize("prefix", ["/data/data/com.termux/files/usr", None])
-def test_android_active(
-    monkeypatch: MonkeyPatch,
+def test_android_active(  # noqa: PLR0913
+    monkeypatch: pytest.MonkeyPatch,
     root: str | None,
     data: str | None,
     path: str,
@@ -78,6 +77,6 @@ def test_android_active(
         root == "/system" and data == "/data" and shell is None and prefix is None and _android_folder() is not None
     )
     if expected:
-        assert platformdirs._set_platform_dir_class() is Android
+        assert platformdirs._set_platform_dir_class() is Android  # noqa: SLF001
     else:
-        assert platformdirs._set_platform_dir_class() is not Android
+        assert platformdirs._set_platform_dir_class() is not Android  # noqa: SLF001
